-- License CC0 (Creative Commons license) (c) darkfrei, 2023

love.window.setMode(800, 800)
W, H = love.graphics.getDimensions( )

function love.load()

	local image = love.graphics.newImage('img-16.png')
	image:setWrap( "repeat" )
	image:setFilter("linear", "nearest")

	local n = 6 -- amount of tiles
	local k = 128 -- size of tile
	local s = n*k -- size of screen

	local vertices = {
		{0, 0, 0, 0, 1,1,1},
		{s, 0, n, 0, 1,1,1},
		{0, s, 0, n, 1,1,1},
		{s, s, n, n, 1,1,1},
	}
	mesh = love.graphics.newMesh( vertices, "strip")
	mesh:setTexture(image)
	Angle = 0

	RE = {angle = 0, x=0, y=0, w=128*n, h=128*n}

end

local function rotateMesh (mesh, s, n, angle, ox, oy)

	ox, oy = ox or 0, oy or 0

	local _cos = math.cos(angle)
	local _sin = math.sin(angle)

	local x1, y1 = 0, 0
	local x2, y2 = s, 0
	local x3, y3 = 0, s
	local x4, y4 = s, s

	local u1 =  (x1 - ox)*_cos + (y1 - oy)*_sin + ox
	local v1 =  (x1 - ox)*_sin - (y1 - oy)*_cos + oy
	local u2 =  (x2 - ox)*_cos + (y2 - oy)*_sin + ox
	local v2 =  (x2 - ox)*_sin - (y2 - oy)*_cos + oy
	local u3 =  (x3 - ox)*_cos + (y3 - oy)*_sin + ox
	local v3 =  (x3 - ox)*_sin - (y3 - oy)*_cos + oy
	local u4 =  (x4 - ox)*_cos + (y4 - oy)*_sin + ox
	local v4 =  (x4 - ox)*_sin - (y4 - oy)*_cos + oy

	local tex_size = s/n

	mesh:setVertex(1, x1, y1, u1/tex_size, v1/tex_size)
	mesh:setVertex(2, x2, y2, u2/tex_size, v2/tex_size)
	mesh:setVertex(3, x3, y3, u3/tex_size, v3/tex_size)
	mesh:setVertex(4, x4, y4, u4/tex_size, v4/tex_size)

end


function love.update(dt)
	Angle = Angle + 0.1*dt
	local n, s = 6, 128*6
	rotateMesh (mesh, s, n, Angle, s/2, s/2)
end


function love.draw()

	--local mx, my = love.mouse.getPosition()
	--love.graphics.translate (mx, my)

	love.graphics.draw(mesh)

end


function love.keypressed(key, scancode, isrepeat)
	if false then
	elseif key == "escape" then
		love.event.quit()
	end
end

function love.mousepressed( x, y, button, istouch, presses )
	if button == 1 then -- left mouse button
	elseif button == 2 then -- right mouse button
	end
end

function love.mousemoved( x, y, dx, dy, istouch )
end

function love.mousereleased( x, y, button, istouch, presses )
	if button == 1 then -- left mouse button
	elseif button == 2 then -- right mouse button
	end
end